@@ -45,22 +45,22 @@ makeSuperCells <- function(X,
     colnames(X) <- paste("cell", 1:N.c, sep = "_")
   }
 
-  X <- X[rowSums(X) > 0,]
-  keep.genes    <- setdiff(rownames(X), genes.exclude)
-  X             <- X[keep.genes, ]
+  X <- X[rowSums(X) > 0, ]
+  keep.genes <- setdiff(rownames(X), genes.exclude)
+  X <- X[keep.genes, ]
 
 
   if (is.null(genes.use)) {
     n.var.genes <- min(n.var.genes, nrow(X))
     if (N.c > 50000) {
       set.seed(seed)
-      idx         <- sample(N.c, 50000)
-      gene.var    <- apply(X[, idx], 1, var)
+      idx <- sample(N.c, 50000)
+      gene.var <- apply(X[, idx], 1, var)
     } else {
-      gene.var    <- apply(X, 1, var)
+      gene.var <- apply(X, 1, var)
     }
 
-    genes.use   <-
+    genes.use <-
       names(sort(gene.var, decreasing = TRUE))[1:n.var.genes]
   }
 
@@ -91,37 +91,38 @@ makeSuperCells <- function(X,
 
   if (do.approx) {
     set.seed(seed)
-    approx.N            <- min(approx.N, N.c)
-    presample           <-
+    approx.N <- min(approx.N, N.c)
+    presample <-
       sample(1:N.c, size = approx.N, replace = FALSE)
     presampled.cell.ids <- colnames(X)[sort(presample)]
-    rest.cell.ids       <- setdiff(colnames(X), presampled.cell.ids)
+    rest.cell.ids <- setdiff(colnames(X), presampled.cell.ids)
   } else {
     presampled.cell.ids <- colnames(X)
-    rest.cell.ids       <- c()
+    rest.cell.ids <- c()
   }
 
-  X.for.pca            <-
+  X.for.pca <-
     Matrix::t(X[genes.use, presampled.cell.ids])
   if (do.scale) {
-    X.for.pca            <- scale(X.for.pca)
+    X.for.pca <- scale(X.for.pca)
   }
   X.for.pca[is.na(X.for.pca)] <- 0
 
   if (is.null(n.pc[1]) |
-      min(n.pc) < 1) {
+    min(n.pc) < 1) {
     stop("Please, provide a range or a number of components to use: n.pc")
   }
-  if (length(n.pc) == 1)
+  if (length(n.pc) == 1) {
     n.pc <- 1:n.pc
+  }
 
   if (fast.pca & (N.c < 1000)) {
-    #warning("Normal PCA is computed because number of cell is low for irlba::irlba()")
+    # warning("Normal PCA is computed because number of cell is low for irlba::irlba()")
     fast.pca <- FALSE
   }
 
   if (!fast.pca) {
-    PCA.presampled          <-
+    PCA.presampled <-
       prcomp(
         X.for.pca,
         rank. = max(n.pc),
@@ -129,9 +130,9 @@ makeSuperCells <- function(X,
         center = F
       )
   } else {
-    PCA.presampled          <-
+    PCA.presampled <-
       irlba::irlba(X.for.pca, n.pc)
-    PCA.presampled$x        <-
+    PCA.presampled$x <-
       PCA.presampled$u %*% diag(PCA.presampled$d)
     PCA.presampled$rotation <- PCA.presampled$v
   }
@@ -146,22 +147,20 @@ makeSuperCells <- function(X,
       directed = directed
     )
 
-  #simplify
+  # simplify
 
-  k   <- round(N.c / gamma)
+  k <- round(N.c / gamma)
 
   if (igraph.clustering[1] == "walktrap") {
-    g.s              <- igraph::cluster_walktrap(sc.nw$graph.knn)
-    g.s$membership   <- igraph::cut_at(g.s, k)
-
+    g.s <- igraph::cluster_walktrap(sc.nw$graph.knn)
+    g.s$membership <- igraph::cut_at(g.s, k)
   } else if (igraph.clustering[1] == "louvain") {
     warning(paste(
       "igraph.clustering =",
       igraph.clustering,
       ", gamma is ignored"
     ))
-    g.s    <- igraph::cluster_louvain(sc.nw$graph.knn)
-
+    g.s <- igraph::cluster_louvain(sc.nw$graph.knn)
   } else {
     stop(
       paste(
@@ -172,12 +171,12 @@ makeSuperCells <- function(X,
     )
   }
 
-  membership.presampled        <- g.s$membership
+  membership.presampled <- g.s$membership
   names(membership.presampled) <- presampled.cell.ids
 
-  SC.NW                        <-
+  SC.NW <-
     igraph::contract(sc.nw$graph.knn, membership.presampled)
-  SC.NW                        <-
+  SC.NW <-
     igraph::simplify(SC.NW, remove.loops = T, edge.attr.comb = "sum")
 
   if (do.approx) {
@@ -231,10 +230,10 @@ makeSuperCells <- function(X,
     #   c(membership.presampled, membership.omitted)
     # membership.all       <- membership.all[colnames(X)]
   } else {
-    membership.all       <- membership.presampled[colnames(X)]
+    membership.all <- membership.presampled[colnames(X)]
   }
 
-  membership  <- membership.all
+  membership <- membership.all
   X <- GE
 
   N.SC <- max(membership)
@@ -242,7 +241,7 @@ makeSuperCells <- function(X,
   j <-
     rep(1:N.SC, supercell_size) # column indices of matrix M.AV that, whene GE.SC <- ge %M.AV%
 
-  goups.idx  <- base::split(seq_len(ncol(X)), membership)#plyr::split_indices(membership)
+  goups.idx <- base::split(seq_len(ncol(X)), membership) # plyr::split_indices(membership)
   i <-
     unlist(goups.idx) # row indices of matrix M.AV that, whene GE.SC <- ge %M.AV%
 
